==> pianobooster_0.7.2.orig.tar.xz: PianoBooster-0.7.2/doc/courses/README.md <==
# Piano Booster Music

These pieces of music have been created to work with _PianoBooster_ and
have the creative commons copyright.
All the music is available [here](https://github.com/captnfab/PianoBooster/raw/master/music/BoosterMusicBooks.zip).

_Please add to the music on this page  - everyone can help._ For more information see this
[forum post](http://piano-booster.2625608.n2.nabble.com/Creating-music-for-PianoBooster-using-MMA-Everyone-can-help-td4167350.html).
The piano parts for were created using the [ABC Plus music](http://abcplus.sourceforge.net/) system,
and the accompaniment was created with the [Musical MIDI Accompaniment (MMA)](http://www.mellowood.ca/mma/).

# Beginners Piano Course

## Find middle C

Here it is. Right in the middle.

## Start with your thumb on Middle C

Press it four times. Wait for four beats then press it again.

## Next play E

Two white notes to the right of C is a note called E. Press it four times.

## Jump over F to get to G

Jump over F to get to G.

## The first five white notes

We will just play the first five notes. Up and down. One note for each finger. (This is the start of the C major scale)

## The C cord

These three notes make a cord of C. Press all the notes together, use your thumb, middle finger and little finger to press all three notes at the same time. Any three note cord is called a triad??????.

## An Arpeggio for the C cord

When you play the notes in a cord one after the other it is called an arpeggio. Play the three notes one at a time, up and down.

## The scale of C Major

All the white notes up to the next c. There are eight notes in a scale. Play scale up and down.

## Our first tune

We are ready to play our first tune.

# Piano Booster Course

## 01-StartWithMiddleC

![score](BeginnerCourse/01-StartWithMiddleC.svg)

**Start With Middle C** is an extremely easy piece. Just find **middle C** on the piano and then play that note four times using your **thumb** on your **right hand**. The first half of the piece has **middle C** in the **Treble Clef**, then for the second half of the piece the same **middle C** note is shown the **Bass Clef**. Play this using your **thumb** on your **left hand**.

**Hint:** _Try to remember where **Middle C** is on the piano - this is the most **important note**!_

[midi file](BeginnerCourse/01-StartWithMiddleC.mid)

## 02-ChordOfCMajor

![score](BeginnerCourse/02-ChordOfCMajor.svg)

The **Chord of C Major** piece, introduces you to the chord of **C Major** which has three notes **Middle C**, **E** and **G**.

Use your **thumb** for **C**, your **middle finger** for **E** and your **little finger** for **G**.

**Hint:** _If you don't know the names of the notes on the score then turn on **Show Note Names** from the PianoBooster **Setup/Preferences** menu._

[midi file](BeginnerCourse/02-ChordOfCMajor.mid)

## 03-UpAndDown

![score](BeginnerCourse/03-UpAndDown.svg)

**Up And Down** uses all the fingers of your right hand to play the first five notes of the **scale of C major**.

Use your **thumb** for **C**, your **index finger** for **D**, . . . , all the way up to your **little finger** for **G**. Make sure you keep using the correct finger for each note.

**Hint:** _If you don't know the notes on the piano then **label the piano keys** using the PianoBooster **Note Chart**._

[midi file](BeginnerCourse/03-UpAndDown.mid)

## 04-ClairDeLaLune

![score](BeginnerCourse/04-ClairDeLaLune.svg)

This is a simplified version of **Clair De La Lune** that uses just three notes **C D** and **E** from your right hand. First find **middle C** and always use your **thumb** for this note, then for **D** use your **first finger** and for **E** use **middle finger**.

**Hint:** _Remember the fingering: Use your **thumb** for **middle C**, your **first finger** for **D** and **middle finger** for **E**._

[midi file](BeginnerCourse/04-ClairDeLaLune.mid)

## 05-ChordOfFMajor

![score](BeginnerCourse/05-ChordOfFMajor.svg)

Now we are going to play using your **left hand** the **F major chord**. The three notes of a chord are called a triad and this chord has the same shape as the C major chord we played earlier but played on a different part of the piano.

Use your **little finger** on the left hand for **F**, your **middle finger** for **A** and your **thumb** for **C**.

**Hint:** _If you don't know the names of the notes on the score then turn on **Show Note Names** from the PianoBooster **Setup/Preferences** menu._

[midi file](BeginnerCourse/05-ChordOfFMajor.mid)

## 06-DownAndUp

![score](BeginnerCourse/06-DownAndUp.svg)

**Down And Up** is mirror version of the Up And Down piece we played earlier but this version uses your **left hand**. These are the top five notes of the scale of C major. Again try to use all your fingers.

Use your **thumb** for **C**, your **index finger** for **B**, . . . , all the way down to your **little finger** for **F**.

**Hint:** _Make sure you use **every finger** on your **left hand** when playing this piece._

[midi file](BeginnerCourse/06-DownAndUp.mid)

## 01-ClairDeLaLune

![score](BoosterMusic/01-ClairDeLaLune.svg)

This is a simplified version of **Clair De La Lune** that uses only the three notes **C D** and **E** from your right hand. First find **middle C** and always use your **thumb** for this note, then for **D** use your **first finger** and for **E** use **middle finger**.

**Hint:** _If you are a complete beginner try the pieces from the **Beginner Course** first._

[midi file](BoosterMusic/01-ClairDeLaLune.mid)

## 02-LavendersBlue

![score](BoosterMusic/02-LavendersBlue.svg)

**Lavender's Blue** is a simple tune in the right hand only that uses the first six notes of the scale of C Major. For the lowest five notes **C D E F** and **G** use all the fingers or your right hand - one for each note. (With your **thumb** on **C** and your **little finger** on **G**). Then for **A** just stretch your **little finger** to reach that note.

**Hint:** _To help find the notes ensure **Show Note Names** are turned on from **Setup Preferences** menu._

[midi file](BoosterMusic/02-LavendersBlue.mid)

## 03-SkipToMyLoo

![score](BoosterMusic/03-SkipToMyLoo.svg)

For **Skip To My Loo** start with both thumbs on **middle C** and then use one finger for each white note on the piano. So for the first two notes which are **E** you should use the **middle finger** of your right hand.

This piece introduces the use of **both hands** as the melody goes across **middle C**.

**Hint:** _For the notes in the **treble clef** you always use your **right hand** and for the **base clef** your **left hand**. Make sure you always keep using the correct finger for each note._

[midi file](BoosterMusic/03-SkipToMyLoo.mid)

## 04-FrereJacques

![score](BoosterMusic/04-FrereJacques.svg)

For **Frere Jacques** introduces the use of playing both hands together with a very simple left hand part. First practice the **left hand** and **right hand** parts separately. Then when ready reduce the **speed to 70%** and try **both hands** together. Again start with **both thumbs** on **Middle C**.

**Hint:** _Practice the **left hand** and **right hand** parts separately._

[midi file](BoosterMusic/04-FrereJacques.mid)

## 05-ScarboroughFair

![score](BoosterMusic/05-ScarboroughFair.svg)

**Scarborough Fair** spans a range of eight notes and so you will have to move fingers up the piano. Use the fingering that you feel comfortable with but ensure that you **use all your fingers** (of your right hand).

**Hint:** _Don't think about what fingers to use, just use the fingering that **comes naturally to you**._

[midi file](BoosterMusic/05-ScarboroughFair.mid)

## 06-Greensleeves

![score](BoosterMusic/06-Greensleeves.svg)

**Green Sleeves** introduces the key of **G major** which has **one Sharp - F#**. Normally the sharp symbol is not shown when **F#** is played (but turning on **Courtesy Accidentals** from the Piano Booster setup/preferences menu will show all accidentals in the key signature). The melody is in the right hand with a simple left hand part.

**Hint:** _You can show **Courtesy Accidentals** from the PianoBooster setup/preferences menu. But remember to **turn them off** when you get more skilled._

[midi file](BoosterMusic/06-Greensleeves.mid)

## 07-AmazingGrace

![score](BoosterMusic/07-AmazingGrace.svg)

**Amazing Grace** introduces the key of **F major** which has a **single Flat - Bb**. Again the flat symbol is not normally shown on the score when playing Bb. Practice both hands separately at first and then when ready reduce the speed to 70% when trying both hands for the first time.

**Hint:** _Reduce the speed to 70% when trying both hands for the first time._

[midi file](BoosterMusic/07-AmazingGrace.mid)

All the music on this page is available [here](https://github.com/captnfab/PianoBooster/raw/master/music/BoosterMusicBooks.zip).
This free sheet music can be used for beginner piano lessons with _PianoBooster_.

==> pianobooster_1.0.0.orig.tar.xz: PianoBooster-1.0.0/doc/courses/README.md <==
# Piano Booster Music

These pieces of music have been created to work with _PianoBooster_ and
have the creative commons copyright.
All the music is available [here](https://github.com/pianobooster/PianoBooster/raw/master/music/BoosterMusicBooks.zip).

_Please add to the music on this page  - everyone can help._ For more information see this
[forum post](http://piano-booster.2625608.n2.nabble.com/Creating-music-for-PianoBooster-using-MMA-Everyone-can-help-td4167350.html).
The piano parts for were created using the [ABC Plus music](http://abcplus.sourceforge.net/) system,
and the accompaniment was created with the [Musical MIDI Accompaniment (MMA)](http://www.mellowood.ca/mma/).

# Beginners Piano Course

## Find middle C

Here it is. Right in the middle.

## Start with your thumb on Middle C

Press it four times. Wait for four beats then press it again.

## Next play E

Two white notes to the right of C is a note called E. Press it four times.

## Jump over F to get to G

Jump over F to get to G.

## The first five white notes

We will just play the first five notes. Up and down. One note for each finger. (This is the start of the C major scale)

## The C cord

These three notes make a cord of C. Press all the notes together, use your thumb, middle finger and little finger to press all three notes at the same time. Any three note cord is called a triad??????.

## An Arpeggio for the C cord

When you play the notes in a cord one after the other it is called an arpeggio. Play the three notes one at a time, up and down.

## The scale of C Major

All the white notes up to the next c. There are eight notes in a scale. Play scale up and down.

## Our first tune

We are ready to play our first tune.

# Piano Booster Course

## 01-StartWithMiddleC

![score](BeginnerCourse/01-StartWithMiddleC.svg)

**Start With Middle C** is an extremely easy piece. Just find **middle C** on the piano and then play that note four times using your **thumb** on your **right hand**. The first half of the piece has **middle C** in the **Treble Clef**, then for the second half of the piece the same **middle C** note is shown the **Bass Clef**. Play this using your **thumb** on your **left hand**.

**Hint:** _Try to remember where **Middle C** is on the piano - this is the most **important note**!_

[midi file](BeginnerCourse/01-StartWithMiddleC.mid)

## 02-ChordOfCMajor

![score](BeginnerCourse/02-ChordOfCMajor.svg)

The **Chord of C Major** piece, introduces you to the chord of **C Major** which has three notes **Middle C**, **E** and **G**.

Use your **thumb** for **C**, your **middle finger** for **E** and your **little finger** for **G**.

**Hint:** _If you don't know the names of the notes on the score then turn on **Show Note Names** from the PianoBooster **Setup/Preferences** menu._

[midi file](BeginnerCourse/02-ChordOfCMajor.mid)

## 03-UpAndDown

![score](BeginnerCourse/03-UpAndDown.svg)

**Up And Down** uses all the fingers of your right hand to play the first five notes of the **scale of C major**.

Use your **thumb** for **C**, your **index finger** for **D**, . . . , all the way up to your **little finger** for **G**. Make sure you keep using the correct finger for each note.

**Hint:** _If you don't know the notes on the piano then **label the piano keys** using the PianoBooster **Note Chart**._

[midi file](BeginnerCourse/03-UpAndDown.mid)

## 04-ClairDeLaLune

![score](BeginnerCourse/04-ClairDeLaLune.svg)

This is a simplified version of **Clair De La Lune** that uses just three notes **C D** and **E** from your right hand. First find **middle C** and always use your **thumb** for this note, then for **D** use your **first finger** and for **E** use **middle finger**.

**Hint:** _Remember the fingering: Use your **thumb** for **middle C**, your **first finger** for **D** and **middle finger** for **E**._

[midi file](BeginnerCourse/04-ClairDeLaLune.mid)

## 05-ChordOfFMajor

![score](BeginnerCourse/05-ChordOfFMajor.svg)

Now we are going to play using your **left hand** the **F major chord**. The three notes of a chord are called a triad and this chord has the same shape as the C major chord we played earlier but played on a different part of the piano.

Use your **little finger** on the left hand for **F**, your **middle finger** for **A** and your **thumb** for **C**.

**Hint:** _If you don't know the names of the notes on the score then turn on **Show Note Names** from the PianoBooster **Setup/Preferences** menu._

[midi file](BeginnerCourse/05-ChordOfFMajor.mid)

## 06-DownAndUp

![score](BeginnerCourse/06-DownAndUp.svg)

**Down And Up** is mirror version of the Up And Down piece we played earlier but this version uses your **left hand**. These are the top five notes of the scale of C major. Again try to use all your fingers.

Use your **thumb** for **C**, your **index finger** for **B**, . . . , all the way down to your **little finger** for **F**.

**Hint:** _Make sure you use **every finger** on your **left hand** when playing this piece._

[midi file](BeginnerCourse/06-DownAndUp.mid)

## 01-ClairDeLaLune

![score](BoosterMusic/01-ClairDeLaLune.svg)

This is a simplified version of **Clair De La Lune** that uses only the three notes **C D** and **E** from your right hand. First find **middle C** and always use your **thumb** for this note, then for **D** use your **first finger** and for **E** use **middle finger**.

**Hint:** _If you are a complete beginner try the pieces from the **Beginner Course** first._

[midi file](BoosterMusic/01-ClairDeLaLune.mid)

## 02-LavendersBlue

![score](BoosterMusic/02-LavendersBlue.svg)

**Lavender's Blue** is a simple tune in the right hand only that uses the first six notes of the scale of C Major. For the lowest five notes **C D E F** and **G** use all the fingers or your right hand - one for each note. (With your **thumb** on **C** and your **little finger** on **G**). Then for **A** just stretch your **little finger** to reach that note.

**Hint:** _To help find the notes ensure **Show Note Names** are turned on from **Setup Preferences** menu._

[midi file](BoosterMusic/02-LavendersBlue.mid)

## 03-SkipToMyLoo

![score](BoosterMusic/03-SkipToMyLoo.svg)

For **Skip To My Loo** start with both thumbs on **middle C** and then use one finger for each white note on the piano. So for the first two notes which are **E** you should use the **middle finger** of your right hand.

This piece introduces the use of **both hands** as the melody goes across **middle C**.

**Hint:** _For the notes in the **treble clef** you always use your **right hand** and for the **base clef** your **left hand**. Make sure you always keep using the correct finger for each note._

[midi file](BoosterMusic/03-SkipToMyLoo.mid)

## 04-FrereJacques

![score](BoosterMusic/04-FrereJacques.svg)

For **Frere Jacques** introduces the use of playing both hands together with a very simple left hand part. First practice the **left hand** and **right hand** parts separately. Then when ready reduce the **speed to 70%** and try **both hands** together. Again start with **both thumbs** on **Middle C**.

**Hint:** _Practice the **left hand** and **right hand** parts separately._

[midi file](BoosterMusic/04-FrereJacques.mid)

## 05-ScarboroughFair

![score](BoosterMusic/05-ScarboroughFair.svg)

**Scarborough Fair** spans a range of eight notes and so you will have to move fingers up the piano. Use the fingering that you feel comfortable with but ensure that you **use all your fingers** (of your right hand).

**Hint:** _Don't think about what fingers to use, just use the fingering that **comes naturally to you**._

[midi file](BoosterMusic/05-ScarboroughFair.mid)

## 06-Greensleeves

![score](BoosterMusic/06-Greensleeves.svg)

**Green Sleeves** introduces the key of **G major** which has **one Sharp - F#**. Normally the sharp symbol is not shown when **F#** is played (but turning on **Courtesy Accidentals** from the Piano Booster setup/preferences menu will show all accidentals in the key signature). The melody is in the right hand with a simple left hand part.

**Hint:** _You can show **Courtesy Accidentals** from the PianoBooster setup/preferences menu. But remember to **turn them off** when you get more skilled._

[midi file](BoosterMusic/06-Greensleeves.mid)

## 07-AmazingGrace

![score](BoosterMusic/07-AmazingGrace.svg)

**Amazing Grace** introduces the key of **F major** which has a **single Flat - Bb**. Again the flat symbol is not normally shown on the score when playing Bb. Practice both hands separately at first and then when ready reduce the speed to 70% when trying both hands for the first time.

**Hint:** _Reduce the speed to 70% when trying both hands for the first time._

[midi file](BoosterMusic/07-AmazingGrace.mid)

All the music on this page is available [here](https://github.com/pianobooster/PianoBooster/raw/master/music/BoosterMusicBooks.zip).
This free sheet music can be used for beginner piano lessons with _PianoBooster_.
